# Ссылка на ошибку

Распространенные ошибки:

- `HandlerSignatureError`
- `RouteDefinitionError`

Руководство:

- Сначала исправьте подписи обработчиков.
- Затем проверьте маршрут DSL и нормализацию.
- Повторный запуск тестов для регрессионной проверки.